#include <IRremote.h>
#include <IRremoteInt.h>
#include <LedWithMillis.h>

LedWithMillis green;
LedWithMillis orange;
LedWithMillis yellow;
LedWithMillis red;
LedWithMillis blue;

int receiver = 11;
long previousIRValue = 0;

IRrecv irrecv(receiver);     
decode_results results;     					

void setup()
{
	green.setup(2);
	orange.setup(3);
	yellow.setup(4);
	red.setup(5);
	blue.setup(6);

	Serial.begin(9600);
	Serial.println("IR Receiver Button Decode");
	irrecv.enableIRIn();
}

void loop()
{
	previousIRValue = results.value;
	//Serial.println(previousIRValue);
	if (irrecv.decode(&results)) // have we received an ir signal?
	{
		translateIR();
		irrecv.resume();
	}

	if (results.value == 0xff30cf) //1
	{
		green.setLedTime(2500, 500, LOW);
		orange.setLedTime(2000, 1000, LOW);
		yellow.setLedTime(1500, 1500, LOW);
		red.setLedTime(1000, 2000, LOW);
		blue.setLedTime(500, 2500, LOW);
	}

	if (results.value == 0xff18e7) //2
	{
		green.setLedTime(2500, 500, HIGH);
		orange.setLedTime(2000, 1000, HIGH);
		yellow.setLedTime(1500, 1500, HIGH);
		red.setLedTime(1000, 2000, HIGH);
		blue.setLedTime(500, 2500, HIGH);
	}

	if (results.value == 0xff7a85) //3
	{
		green.setLedTime(500, 2500, LOW);
		orange.setLedTime(1000, 2000, LOW);
		yellow.setLedTime(2500, 500, LOW);
		red.setLedTime(1000, 2000, LOW);
		blue.setLedTime(500, 2500, LOW);
	}

	if (results.value == 0xff10ef) //4
	{
		green.setLedTimeAndChanceMillis(2000, 500, 2500, LOW);
		orange.setLedTimeAndChanceMillis(1500, 500, 2500, LOW);
		yellow.setLedTimeAndChanceMillis(1000, 500, 2500, LOW);
		red.setLedTimeAndChanceMillis(500, 500, 2500, LOW);
		blue.setLedTimeAndChanceMillis(0, 500, 2500, LOW);
	}

	if (results.value == 0xff38c7) //5
	{
		ledsOn();
	}

	if (results.value == 0xFFA25D) //power
	{
		ledsOff();
	}
}

void ledsOff()
{
	digitalWrite(2, LOW);
	digitalWrite(3, LOW);
	digitalWrite(4, LOW);
	digitalWrite(5, LOW);
	digitalWrite(6, LOW);
}

void ledsOn()
{
	digitalWrite(2, HIGH);
	digitalWrite(3, HIGH);
	digitalWrite(4, HIGH);
	digitalWrite(5, HIGH);
	digitalWrite(6, HIGH);
}

void translateIR()

{
	switch (results.value)
	{
	case 0xFFA25D: Serial.println("POWER"); break;
	case 0xFFE21D: Serial.println("FUNC/STOP"); break;
	case 0xFF629D: Serial.println("VOL+"); break;
	case 0xFF22DD: Serial.println("FAST BACK");    break;
	case 0xFF02FD: Serial.println("PAUSE");    break;
	case 0xFFC23D: Serial.println("FAST FORWARD");   break;
	case 0xFFE01F: Serial.println("DOWN");    break;
	case 0xFFA857: Serial.println("VOL-");    break;
	case 0xFF906F: Serial.println("UP");    break;
	case 0xFF9867: Serial.println("EQ");    break;
	case 0xFFB04F: Serial.println("ST/REPT");    break;
	case 0xFF6897: Serial.println("0");    break;
	case 0xFF30CF: Serial.println("1");    break;
	case 0xFF18E7: Serial.println("2");    break;
	case 0xFF7A85: Serial.println("3");    break;
	case 0xFF10EF: Serial.println("4");    break;
	case 0xFF38C7: Serial.println("5");    break;
	case 0xFF5AA5: Serial.println("6");    break;
	case 0xFF42BD: Serial.println("7");    break;
	case 0xFF4AB5: Serial.println("8");    break;
	case 0xFF52AD: Serial.println("9");    break;
	case 0xFFFFFFFF: Serial.println(" REPEAT"); break;

	default:
		{
			Serial.println(" other button   ");
			results.value = previousIRValue;
			Serial.println(results.value);
		}

	}
	delay(500);
}